@@ -1,5 +1,7 @@
 """Customized PyDaymet exceptions."""
-from typing import Any, Generator, Iterable, List, Optional, Union
+from __future__ import annotations
+
+from typing import Any, Generator, Iterable
 
 
 class InputValueError(Exception):
@@ -13,12 +15,9 @@ class InputValueError(Exception):
         List of valid inputs
     """
 
-    def __init__(
-        self, inp: str, valid_inputs: Union[Iterable[Any], Generator[str, None, None]]
-    ) -> None:
-        self.message = f"Given {inp} is invalid. Valid {inp}s are:\n" + ", ".join(
-            str(i) for i in valid_inputs
-        )
+    def __init__(self, inp: str, valid_inputs: Iterable[Any] | Generator[str, None, None]) -> None:
+        valid = ", ".join(str(i) for i in valid_inputs)
+        self.message = f"Valid values for {inp} are:\n{valid}"
         super().__init__(self.message)
 
     def __str__(self) -> str:
@@ -38,7 +37,7 @@ class InputTypeError(Exception):
         An example of a valid form of the argument, defaults to None.
     """
 
-    def __init__(self, arg: str, valid_type: str, example: Optional[str] = None) -> None:
+    def __init__(self, arg: str, valid_type: str, example: str | None = None) -> None:
         self.message = f"The {arg} argument should be of type {valid_type}"
         if example is not None:
             self.message += f":\n{example}"
@@ -48,8 +47,23 @@ class InputTypeError(Exception):
         return self.message
 
 
-class InputRangeError(ValueError):
-    """Exception raised when a function argument is not in the valid range."""
+class InputRangeError(Exception):
+    """Exception raised when a function argument is not in the valid range.
+
+    Parameters
+    ----------
+    variable : str
+        Variable with invalid value
+    valid_range : str
+        Valid range
+    """
+
+    def __init__(self, variable: str, valid_range: str) -> None:
+        self.message = f"Valid range for {variable} is {valid_range}."
+        super().__init__(self.message)
+
+    def __str__(self) -> str:
+        return self.message
 
 
 class MissingItemError(Exception):
@@ -61,7 +75,7 @@ class MissingItemError(Exception):
         A list of missing items.
     """
 
-    def __init__(self, missing: List[str]) -> None:
+    def __init__(self, missing: list[str]) -> None:
         self.message = "The following items are missing:\n" + f"{', '.join(missing)}"
         super().__init__(self.message)
 
