@@ -13,14 +13,13 @@ import pandas as pd
 import pygeoogc as ogc
 import pygeoutils as geoutils
 import pyproj
-import rioxarray  # noqa: F401
 import xarray as xr
 from pygeoogc import ServiceError, ServiceURL
 from pygeoutils import Coordinates
 
-from .core import T_RAIN, T_SNOW, Daymet
-from .exceptions import InputRangeError, InputTypeError
-from .pet import potential_et
+from pydaymet.core import T_RAIN, T_SNOW, Daymet
+from pydaymet.exceptions import InputRangeError, InputTypeError
+from pydaymet.pet import potential_et
 
 if TYPE_CHECKING:
     from shapely.geometry import MultiPolygon, Polygon
@@ -148,7 +147,7 @@ def _by_coord(
         (
             pd.concat(
                 pd.read_csv(io.StringIO(r), parse_dates=[0], usecols=[0, 3], index_col=[0])
-                for r in retrieve(u, k)
+                for r in retrieve(u, k)  # type: ignore
             )
             for u, k in (zip(*u) for u in url_kwds)
         ),
