@@ -4,7 +4,7 @@ import shutil
 import sys
 from pathlib import Path
 
-import cytoolz as tlz
+import cytoolz.curried as tlz
 import geopandas as gpd
 import numpy as np
 import pandas as pd
